@@ -13,12 +13,7 @@ from meutils.io.image import image_read
 
 from paddleocr import PaddleOCR
 
-
-
 model = PaddleOCR()
-main = pickle_cache(model.ocr, location='ocr_cache')
-
-
 
 if __name__ == '__main__':
-    print(main(image_read('image.png')))
\ No newline at end of file
+    print(model.ocr(image_read('image.png')))
